local ItemFilter = require("CraftingFramework.carryableContainers.components.ItemFilter")

---@alias CarryableContainers.DefaultItemFilter
---| '"apparatus"'
---| '"armor"'
---| '"books"'
---| '"clothing"'
---| '"ingredients"'
---| '"lights"'
---| '"thiefTools"'
---| '"miscellanous"'
---| '"potions"'
---| '"repairItems"'
---| '"weapons"'
---| '"attire"'
---| '"equipment"'
---| '"jewelry"'

---@type CarryableContainers.ItemFilter.new.data[]
local itemFilters = {
    --For each tes3.objectType
    {
        id = "apparatus",
        name = "",
        objectTypes = {
            [tes3.objectType.apparatus] = true
        },
    },
    {
        id = "armor",
        name = "",
        objectTypes = {
            [tes3.objectType.armor] = true
        }
    },
    {
        id = "books",
        name = "",
        objectTypes = {
            [tes3.objectType.book] = true
        }
    },
    {
        id = "clothing",
        name = "",
        objectTypes = {
            [tes3.objectType.clothing] = true
        }
    },
    {
        id = "ingredients",
        name = "",
        objectTypes = {
            [tes3.objectType.ingredient] = true
        }
    },
    {
        id = "lights",
        name = "",
        objectTypes = {
            [tes3.objectType.light] = true
        }
    },
    {
        id = "thiefTools",
        name = " ",
        objectTypes = {
            [tes3.objectType.lockpick] = true,
            [tes3.objectType.probe] = true

        }
    },
    {
        id = "miscellanous",
        name = "",
        objectTypes = {
            [tes3.objectType.miscItem] = true
        }
    },
    {
        id = "potions",
        name = "",
        objectTypes = {
            [tes3.objectType.alchemy] = true
        }
    },
    {
        id = "repairItems",
        name = "  ",
        objectTypes = {
            [tes3.objectType.repairItem] = true
        }
    },
    {
        id = "weapons",
        name = "",
        objectTypes = {
            [tes3.objectType.weapon] = true
        }
    },
    {
        id = "attire",
        name = "",
        objectTypes = {
            [tes3.objectType.armor] = true,
            [tes3.objectType.clothing] = true,
        }
    },
    {
        id = "equipment",
        name = "",
        objectTypes = {
            [tes3.objectType.armor] = true,
            [tes3.objectType.weapon] = true
        }
    },
    {
        id = "jewelry",
        name = " ",
        isValidItem = function(item, itemData)
            ---@cast item tes3clothing
            local isClothing = item.objectType == tes3.objectType.clothing
            local isRing = item.slot == tes3.clothingSlot.ring
            local isAmulet = item.slot == tes3.clothingSlot.amulet
            return isClothing and (isRing or isAmulet)
        end,
    }
}

for _, itemFilter in ipairs(itemFilters) do
    ItemFilter.register(itemFilter)
end