local config = require("CraftingFramework.config")
local Util = require("CraftingFramework.util.Util")
local mcmConfig = mwse.loadConfig(config.configPath, config.mcmDefault)

local LINKS_LIST = {
    {
        text = " ",
        url = "https://github.com/jhaakma/crafting-framework/releases"
    },
    {
        text = "",
        url = "https://github.com/jhaakma/crafting-framework/wiki"
    },
    {
        text = "   Nexusmods",
        url = "https://www.nexusmods.com/morrowind/mods/51009"
    },
    {
        text = " ",
        url = "https://ko-fi.com/merlord"
    },
}
local CREDITS_LIST = {
    {
        text = ": Merlord",
        url = "https://www.nexusmods.com/users/3040468?tab=user+files",
    },
    {
        text = ": SpratlyNation",
        url = "https://www.facebook.com/VideoGame360Pano",
    },
    {
        text = "Help with type definitions from C3pa",
        url = "https://www.nexusmods.com/morrowind/users/37172285"
    }
}
local SIDE_BAR_DEFAULT =
[[         .        ,         ,      .]]

local function addSideBar(component)
    local versionText = string.format(" ,  1.23.4")
    component.sidebar:createCategory(versionText)
    component.sidebar:createInfo{ text = SIDE_BAR_DEFAULT}

    local linksCategory = component.sidebar:createCategory(":")
    for _, link in ipairs(LINKS_LIST) do
        linksCategory:createHyperLink{ text = link.text, url = link.url }
    end
    local creditsCategory = component.sidebar:createCategory(":")
    for _, credit in ipairs(CREDITS_LIST) do
        creditsCategory:createHyperLink{ text = credit.text, url = credit.url }
    end
end


local function registerMCM()
    local template = mwse.mcm.createTemplate{ name = " " }
    template.onClose = function()
        config.save(mcmConfig)
    end
    template:register()

    local page = template:createSideBarPage{ label = ""}
    addSideBar(page)
    page:createDropdown{
        label = "Log Level",
        description = "     mwse.log.  INFO,    .",
        options = {
            { label = "TRACE", value = "TRACE"},
            { label = "DEBUG", value = "DEBUG"},
            { label = "INFO", value = "INFO"},
            { label = "ERROR", value = "ERROR"},
            { label = "NONE", value = "NONE"},
        },
        variable =  mwse.mcm.createTableVariable{ id = "logLevel", table = mcmConfig },
        callback = function(self)
            for _, logger in pairs(Util.loggers) do
                logger:setLogLevel(self.variable.value)
                ---@diagnostic disable-next-line
                logger:info("New Log Level: %s", logger.logLevel)
            end
        end
    }

    page:createSlider{
        label = " : %s%%",
        description = "      .          .  : 75%",
        min = 0,
        max = 100,
        step = 1,
        variable = mwse.mcm.createTableVariable{ id = "defaultMaterialRecovery", table = mcmConfig },
    }

    page:createKeyBinder{
        label = "    ",
        description = "     `quickActivateCallback`.  : Left Shift",
        allowCombinations = false,
        variable = mwse.mcm.createTableVariable{ id = "quickModifierHotkey", table = mcmConfig },
    }

    page:createYesNoButton{
        label = "  ",
        description = "  ,          .      .",
        variable = mwse.mcm.createTableVariable{ id = "enableInfiniteStorage", table = config.mcm },
    }
end
event.register("modConfigReady", registerMCM)